@@ -38,7 +38,7 @@ table_data_order = Qt.UserRole + 2  # sorting order (for custom sorting, used fo
 
 
 class Window(QtWidgets.QMainWindow):
-  def __init__(self, args):
+  def __init__(self, max_hidden_history, window_title, clear_settings):
     super(Window, self).__init__(parent=None)
     
     self.experiments = None  # object that manages experiments
@@ -46,11 +46,13 @@ class Window(QtWidgets.QMainWindow):
     self.visualizations = None  # object that manages custom visualizations
     self.last_process_events = time()  # to update during heavy loads
     self.rebuilding_plots = False  # used by rebuild_plots
-    self.max_hidden_history = args.max_hidden_history
+    self.max_hidden_history = max_hidden_history
     self.selected_first_exp = False  # select first experiment to load meta, for discoverability
 
     # persistent settings
     self.settings = QtCore.QSettings('OverBoard', 'OverBoard')
+    if clear_settings:
+      self.settings.clear()  # clean slate
 
     # get screen size
     screen_size = QtWidgets.QDesktopWidget().availableGeometry(self).size()
@@ -169,6 +171,7 @@ class Window(QtWidgets.QMainWindow):
     table.setSizeAdjustPolicy(QtWidgets.QAbstractScrollArea.AdjustToContents)
     table.setHorizontalScrollMode(QtWidgets.QAbstractItemView.ScrollPerPixel)  # smooth scrolling
     table.setVerticalScrollMode(QtWidgets.QAbstractItemView.ScrollPerPixel)
+    table.setItemDelegate(ElidedTextItemDelegate())  # fix bug where text is not elided properly
     
     table.verticalHeader().hide()  # hide vertical header
     
@@ -208,7 +211,7 @@ class Window(QtWidgets.QMainWindow):
 
     # window size and title
     self.resize(screen_size.width() * 0.6, screen_size.height() * 0.95)
-    self.setWindowTitle('OverBoard - ' + args.folder)
+    self.setWindowTitle(window_title)
 
     self.clipboard = QtWidgets.QApplication.clipboard()
 
@@ -235,6 +238,7 @@ class Window(QtWidgets.QMainWindow):
     if not reuse:
       label = QtWidgets.QLabel(title)
       label.setAlignment(Qt.AlignCenter)
+      label.mousePressEvent = lambda _: self.on_panel_title_click(panel)
 
       vbox = QtWidgets.QVBoxLayout()
       vbox.addWidget(label, stretch=0)
@@ -255,8 +259,27 @@ class Window(QtWidgets.QMainWindow):
     if add_to_layout and not reuse:  # add to window's flow layout
       self.flow_layout.addWidget(panel)
 
+    self.sort_panels()  # sort to place this panel in the right place
     return panel
   
+  def on_panel_title_click(self, panel):
+    """Hide or show a panel's content, when its title text is clicked"""
+    if panel.plot_widget.isVisible():
+      panel.plot_widget.hide()
+      panel.setFixedHeight(2 * panel.title_widget.height())
+      panel.title_widget.setText(panel.title_widget.text() + ' (hidden)')
+      panel.title_widget.setStyleSheet('color: #909090')
+    else:
+      panel.plot_widget.show()
+      panel.setFixedHeight(self.size_slider.value())
+      panel.title_widget.setText(panel.title_widget.text()[:-len(' (hidden)')])
+      panel.title_widget.setStyleSheet('')
+    self.sort_panels()  # move the hidden panel to the end, or back again
+
+  def sort_panels(self):
+    """Sort the panels alphabetically by title (and some other rules)"""
+    self.flow_layout._items.sort(key=get_panel_sort_key)
+
   def create_dropdown(self, sidebar, label, options, setting_name, default='', reset_style=False, checkable=False, return_label=False):
     """Create a new dropdown menu, associated with a persistent setting"""
     rows = sidebar.rowCount()
@@ -780,6 +803,41 @@ class CheckableComboBox(QtWidgets.QComboBox):
     return [str(item.text()) for item in items if item.checkState() == state]
 
 
+class ElidedTextItemDelegate(QtWidgets.QStyledItemDelegate):
+  """Helper delegate to draw proper elided text (i.e. cut off with ...) in tables"""
+  def paint(self, painter, option, index):
+    if not index.isValid():
+      return
+
+    # modify a copy of the options
+    opt = QtWidgets.QStyleOptionViewItem(option)
+    self.initStyleOption(opt, index)
+    style = QtWidgets.QApplication.style()
+
+    # reduce the rect a bit
+    painter.save()
+    painter.setClipRect(opt.rect)
+    padding = 3
+    opt.rect = opt.rect.adjusted(padding, padding, -padding, -padding)
+
+    # elide the text as a string
+    text = opt.fontMetrics.elidedText(opt.text, Qt.ElideRight, opt.rect.width())
+
+    # draw it, with the proper role (i.e. color if selected)
+    text_role = QtGui.QPalette.NoRole
+    if option.state & style.State_Selected:
+      text_role = QtGui.QPalette.HighlightedText
+    style.drawItemText(painter, opt.rect, opt.displayAlignment,
+      opt.palette, True, text, text_role)
+
+    # draw the item again with empty text to complete it
+    painter.restore()
+    opt.rect = option.rect
+    opt.textElideMode = Qt.ElideNone
+    opt.text = ""
+    style.drawControl(QtWidgets.QStyle.CE_ItemViewItem, opt, painter, opt.widget)
+
+
 def create_scroller():
   scroll_area = QtWidgets.QScrollArea()
   scroll_area.setWidgetResizable(True)
@@ -799,6 +857,16 @@ def print_datetime(dt):
   return f"{dt.day} {dt:%b %Y, %X}"  # day month year, time
 
 
+def get_panel_sort_key(item):
+  """Get a key from a panel for sorting.
+  They are sorted by title, but we want visualizations to come second,
+  and hidden/minimized panels last."""
+  widget = item.widget()
+  return (not widget.plot_widget.isVisible(),  # visible panels come first
+    not hasattr(widget.plot_widget, 'is_experiment_plot'),  # then experiment plots
+    widget.title_widget.text())  # all else being equal, sort titles alphabetically
+
+
 def set_style(app):
   app.setStyle("Fusion")
 
